Skip to content
Commits on Source (6)
tree-puzzle (5.2-11) unstable; urgency=medium
* debhelper 11
* Point Vcs fields to salsa.debian.org
* Standards-Version: 4.2.1
* Fix some spelling issues
-- Andreas Tille <tille@debian.org> Tue, 16 Oct 2018 11:06:43 +0200
tree-puzzle (5.2-10) unstable; urgency=medium
* Do not try parallel builds
......
......@@ -4,12 +4,12 @@ Uploaders: Andreas Tille <tille@debian.org>,
Charles Plessy <plessy@debian.org>
Section: science
Priority: optional
Build-Depends: debhelper (>= 10),
Build-Depends: debhelper (>= 11~),
libopenmpi-dev,
libsprng2-dev
Standards-Version: 4.1.1
Vcs-Browser: https://anonscm.debian.org/cgit/debian-med/tree-puzzle.git
Vcs-Git: https://anonscm.debian.org/git/debian-med/tree-puzzle.git
Standards-Version: 4.2.1
Vcs-Browser: https://salsa.debian.org/med-team/tree-puzzle
Vcs-Git: https://salsa.debian.org/med-team/tree-puzzle.git
Homepage: http://www.tree-puzzle.de
Package: tree-puzzle
......
20_no_copy_of_sprng.patch
tests-need-bash.patch
spelling.patch
Description: Fix some spelling issues
Author: Andreas Tille <tille@debian.org>
Last-Update: Tue, 16 Oct 2018 10:51:06 +0200
--- a/src/ml2.c
+++ b/src/ml2.c
@@ -417,7 +417,7 @@ Node *internalnode(Tree *tr, char **chpp
if (!strcmp(ident, idcomp)) {
if (usedtaxa[i]) {
- fprintf(STDOUT, "\n\n\nUnable to proceed (multiple occurence of sequence '");
+ fprintf(STDOUT, "\n\n\nUnable to proceed (multiple occurrence of sequence '");
fprintf(STDOUT, "%s' in tree)\n\n\n", ident);
# if PARALLEL
PP_Finalize();
--- a/src/puzzle1.c
+++ b/src/puzzle1.c
@@ -1967,7 +1967,7 @@ void initps(FILE *ofp)
/* PS definition of a centered print */
fprintf(ofp, "/centershow {\n");
fprintf(ofp, " dup stringwidth pop %% get length of string\n");
- fprintf(ofp, " -2 div %% devide length by -2\n");
+ fprintf(ofp, " -2 div %% divide length by -2\n");
fprintf(ofp, " 0 rmoveto %% move half width to left\n");
fprintf(ofp, " show\n");
fprintf(ofp, "} def\n");
@@ -3538,7 +3538,7 @@ void writeoutputfile(FILE *ofp, int part
i+1, Rates[i], (1.0-fracinv)/(double) numcats);
}
if (rhetmode == GAMMARATE || rhetmode == MIXEDRATE) {
- fprintf(ofp, "\nCategories 1-%d approximate a continous ", numcats);
+ fprintf(ofp, "\nCategories 1-%d approximate a continuous ", numcats);
fprintf(ofp, "Gamma-distribution with expectation 1\n");
fprintf(ofp, "and variance ");
if (Geta == 1.0) fprintf(ofp, "infinity");
@@ -5231,21 +5231,21 @@ void printusagehhh(char *fname)
#ifdef HHH
/* |<--- 80 characters --->| */
fprintf(stderr, " not yet implemented in this version:\n");
- fprintf(stderr, " -wslb - write site lhs to PREFIX.sitelhb (binary) [not yet]\n");
- fprintf(stderr, " -wsrb - write site rates to PREFIX.siterateb (binary) [not yet]\n");
- fprintf(stderr, " -wparam - write params to PREFIX.param [not yet]\n");
- fprintf(stderr, " -qsupport - prints quartet support for incorporated splits [not yet]\n");
- fprintf(stderr, " -consth=<#> - consensus threshold, e.g. 50=M_50 consensus [not yet]\n");
- fprintf(stderr, " -wqnex - write quartets in nexus format [not yet]\n");
- fprintf(stderr, " -wsnex - write splits in nexus format [not yet]\n");
- fprintf(stderr, " -wsth=<#> - split threshold, e.g. 50 - splits of the M_50 [not yet]\n");
- fprintf(stderr, " -wsnex=<#> - write splits with > <#>%% occurence - nexus format[not yet]\n");
- fprintf(stderr, " -witnex - write intermediate trees in nexus format [not yet]\n");
- fprintf(stderr, " -quartml - use ML values to evaluate quartets [not yet]\n");
- fprintf(stderr, " -quartmlapprox - use approximate ML values to evaluate quartets [default]\n");
- fprintf(stderr, " -quartnj - use NJ to evaluate quartets [not yet]\n");
- fprintf(stderr, " -quartme - use ME to evaluate quartets [not yet]\n");
- fprintf(stderr, " -quartpars - use parsimony to evaluate quartets [not yet]\n");
+ fprintf(stderr, " -wslb - write site lhs to PREFIX.sitelhb (binary) [not yet]\n");
+ fprintf(stderr, " -wsrb - write site rates to PREFIX.siterateb (binary) [not yet]\n");
+ fprintf(stderr, " -wparam - write params to PREFIX.param [not yet]\n");
+ fprintf(stderr, " -qsupport - prints quartet support for incorporated splits [not yet]\n");
+ fprintf(stderr, " -consth=<#> - consensus threshold, e.g. 50=M_50 consensus [not yet]\n");
+ fprintf(stderr, " -wqnex - write quartets in nexus format [not yet]\n");
+ fprintf(stderr, " -wsnex - write splits in nexus format [not yet]\n");
+ fprintf(stderr, " -wsth=<#> - split threshold, e.g. 50 - splits of the M_50 [not yet]\n");
+ fprintf(stderr, " -wsnex=<#> - write splits with > <#>%% occurrence - nexus format[not yet]\n");
+ fprintf(stderr, " -witnex - write intermediate trees in nexus format [not yet]\n");
+ fprintf(stderr, " -quartml - use ML values to evaluate quartets [not yet]\n");
+ fprintf(stderr, " -quartmlapprox - use approximate ML values to evaluate quartets [default]\n");
+ fprintf(stderr, " -quartnj - use NJ to evaluate quartets [not yet]\n");
+ fprintf(stderr, " -quartme - use ME to evaluate quartets [not yet]\n");
+ fprintf(stderr, " -quartpars - use parsimony to evaluate quartets [not yet]\n");
fprintf(stderr, "\n");
#endif /* HHH */
--- a/src/puzzle2.c
+++ b/src/puzzle2.c
@@ -68,7 +68,7 @@ void readid(FILE *infp, int t)
if (Identif[t][j] != Identif[i][j])
flag = FALSE;
if (flag) {
- fprintf(STDOUT, "\n\n\nUnable to proceed (multiple occurence of sequence name '");
+ fprintf(STDOUT, "\n\n\nUnable to proceed (multiple occurrence of sequence name '");
fputid(STDOUT, t);
fprintf(STDOUT, "')\n\n\n");
# if PARALLEL
--- a/src/treesort.c
+++ b/src/treesort.c
@@ -601,7 +601,7 @@ treelistitemtype *addtree2list(char
/**********/
/* resort list of trees by number of occurences for output */
void sortbynum(treelistitemtype *list, treelistitemtype **sortlist)
{
treelistitemtype *tmpptr = NULL;
@@ -721,9 +721,9 @@ void fprintfsortedpstrees(FILE *output,
if (num == 1){
fprintf (output, "\n");
fprintf (output, "The following tree(s) occured in more than %.2f%% of the %d puzzling steps.\n", cutoff, itemsum);
- fprintf (output, "The trees are orderd descending by the number of occurences.\n");
+ fprintf (output, "The trees are orderd descending by the number of occurrences.\n");
fprintf (output, "\n");
- fprintf (output, "\n occurences ID Phylip tree\n");
+ fprintf (output, "\n occurrences ID Phylip tree\n");
}
fprintf (output, "%2d. %5d %6.2f%% %5d ", num++, (*tmpptr).count, percent, (*tmpptr).id);
}
@@ -601,7 +601,7 @@ treelistitemtype *addtree2list(char
/**********/
-/* resort list of trees by number of occurences for output */
+/* resort list of trees by number of occurrences for output */
void sortbynum(treelistitemtype *list, treelistitemtype **sortlist)
{
......@@ -6,4 +6,4 @@ Abstract: Maximum likelihood analysis for nucleotide, amino acid, and two-state
Section: Science/Biology
Format: pdf
Files: /usr/share/doc/tree-puzzle-doc/tree-puzzle.pdf
Files: /usr/share/doc/tree-puzzle/tree-puzzle.pdf